@@ -23,10 +23,6 @@
 #ifndef __XFPM_CONFIG_H
 #define __XFPM_CONFIG_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glib.h>
 
 G_BEGIN_DECLS
@@ -76,11 +72,14 @@ G_BEGIN_DECLS
 #define BRIGHTNESS_LEVEL_ON_AC               "brightness-level-on-ac"
 #define BRIGHTNESS_LEVEL_ON_BATTERY          "brightness-level-on-battery"
 #define BRIGHTNESS_SLIDER_MIN_LEVEL          "brightness-slider-min-level"
+#define BRIGHTNESS_STEP_COUNT                "brightness-step-count"
+#define BRIGHTNESS_EXPONENTIAL               "brightness-exponential"
 #define BRIGHTNESS_SWITCH                    "brightness-switch"
 #define BRIGHTNESS_SWITCH_SAVE               "brightness-switch-restore-on-exit"
 #define HANDLE_BRIGHTNESS_KEYS               "handle-brightness-keys"
 #define SHOW_BRIGHTNESS_POPUP                "show-brightness-popup"
 #define SHOW_PANEL_LABEL                     "show-panel-label"
+#define SHOW_PRESENTATION_INDICATOR          "show-presentation-indicator"
 
 G_END_DECLS
 
