@@ -141,7 +141,6 @@ power_manager_plugin_configure (XfcePanelPlugin      *plugin,
   GtkWidget *dialog;
   GtkWidget *grid, *combo, *label, *gtkswitch;
   gint show_panel_label;
-  gboolean show_presentation_indicator;
   XfconfChannel   *channel;
   GtkListStore *list_store;
   GtkTreeIter iter, active_iter;
@@ -214,7 +213,6 @@ power_manager_plugin_configure (XfcePanelPlugin      *plugin,
   label = gtk_label_new (_("Show 'Presentation mode' indicator:"));
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (label), 0, 1, 1, 1);
-  show_presentation_indicator = xfconf_channel_get_bool (channel, XFPM_PROPERTIES_PREFIX SHOW_PRESENTATION_INDICATOR, -1);
 
   gtkswitch = gtk_switch_new ();
   gtk_widget_set_halign (gtkswitch, GTK_ALIGN_END);
