@@ -897,7 +897,7 @@ xfpm_power_add_device (UpDevice *device, XfpmPower *power)
     GtkWidget *battery;
     XFPM_DEBUG( "Battery device type '%s' detected at: %s",
                 up_device_kind_to_string(device_type), object_path);
-    battery = xfpm_battery_new ();
+    battery = g_object_ref_sink (xfpm_battery_new ());
 
     xfpm_battery_monitor_device (XFPM_BATTERY (battery),
                                  object_path,
@@ -952,6 +952,8 @@ xfpm_power_inhibit_changed_cb (XfpmInhibit *inhibit, gboolean is_inhibit, XfpmPo
                 power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
                 power->priv->presentation_mode ? "TRUE" : "FALSE");
 
+    xfpm_dpms_inhibit (power->priv->dpms, is_inhibit);
+
     /* If we are inhibited make sure we inhibit the screensaver too */
     if (is_inhibit)
     {
@@ -976,6 +978,8 @@ xfpm_power_inhibit_changed_cb (XfpmInhibit *inhibit, gboolean is_inhibit, XfpmPo
   power->priv->inhibited ? "TRUE" : "FALSE",
   power->priv->screensaver_inhibited ? "TRUE" : "FALSE",
   power->priv->presentation_mode ? "TRUE" : "FALSE");
+
+  xfpm_update_blank_time (power);
 }
 
 static void
@@ -1436,8 +1440,8 @@ xfpm_update_blank_time (XfpmPower *power)
   else
     screensaver_timeout = power->priv->on_ac_blank;
 
-    /* Presentation mode disables blanking */
-  if (power->priv->presentation_mode)
+    /* Presentation mode or inhibited disables blanking */
+  if (power->priv->presentation_mode || power->priv->inhibited)
     screensaver_timeout = 0;
 
   screensaver_timeout = screensaver_timeout * 60;
